@@ -66,7 +66,7 @@ class Orden(BaseModel):
         mensaje = etree.Element('mensaje', categoria=self.categoria)
         orden_pago = etree.SubElement(mensaje, 'ordenpago')
 
-        for element, value in self.json(exclude_none=True, exclude={'categoria', 'op_ord_clave'}).items():  # noqa: WPS110, WPS221, E501
+        for element, value in self.dict(exclude_none=True, exclude={'categoria', 'op_ord_clave'}).items():  # noqa: WPS110, WPS221, E501
             if element in self.__fields__:
                 if element == 'op_firma_dig':
                     subelement = etree.SubElement(orden_pago, 'opFirmaDig')
@@ -84,7 +84,7 @@ class Orden(BaseModel):
         body = orden.find('{http://schemas.xmlsoap.org/soap/envelope/}Body')
         orden_pago = body.find('{http://www.praxis.com.mx/}ordenpago')
 
-        mensaje_xml = etree.fromstring(orden_pago.text)  # noqa: S320
+        mensaje_xml = etree.fromstring(bytes(orden_pago.text, encoding='cp850'))  # noqa: S320, E501
         orden = mensaje_xml.find('ordenpago')
 
         orden_data = {
@@ -114,7 +114,7 @@ class Respuesta(BaseModel):
         mensaje = etree.Element('mensaje', categoria=self.categoria)
         orden_pago = etree.SubElement(mensaje, 'respuesta')
 
-        for element, value in self.dict(exclude={'categoria',}).items():  # noqa: WPS110
+        for element, value in self.dict(exclude={'categoria'}).items():  # noqa: WPS110
             if element in self.__fields__:
                 upper_camel_case_element = to_upper_camel_case(element)
                 subelement = etree.SubElement(orden_pago, upper_camel_case_element)
